@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 1993-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 1993-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -40,6 +40,9 @@
 #include <ctrl/ctrl0073/ctrl0073system.h>
 #include <ctrl/ctrl5070/ctrl5070or.h>
 
+#include "displayport2x.h"
+#include "dp_evoadapter2x.h"
+
 using namespace DisplayPort;
 
 //
@@ -94,10 +97,16 @@ const struct
     {NV_DP_DSC_MST_CAP_BUG_3143315,                 &dpRegkeyDatabase.bDscMstCapBug3143315,            DP_REG_VAL_BOOL},
     {NV_DP_REGKEY_POWER_DOWN_PHY,                   &dpRegkeyDatabase.bPowerDownPhyBeforeD3,           DP_REG_VAL_BOOL},
     {NV_DP_REGKEY_REASSESS_MAX_LINK,                &dpRegkeyDatabase.bReassessMaxLink,                DP_REG_VAL_BOOL},
+    {NV_DP2X_REGKEY_FPGA_UHBR_SUPPORT,              &dpRegkeyDatabase.supportInternalUhbrOnFpga,       DP_REG_VAL_U32},
+    {NV_DP2X_IGNORE_CABLE_ID_CAPS,                  &dpRegkeyDatabase.bIgnoreCableIdCaps,              DP_REG_VAL_BOOL},
     {NV_DP_REGKEY_MST_PCON_CAPS_READ_DISABLED,      &dpRegkeyDatabase.bMSTPCONCapsReadDisabled,        DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_FORCE_DSC_ON_SINK,                &dpRegkeyDatabase.bForceDscOnSink,                 DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_ENABLE_SKIP_DPCD_READS_WAR,       &dpRegkeyDatabase.bSkipFakeDeviceDpcdAccess,       DP_REG_VAL_BOOL},
-    {NV_DP_REGKEY_DISABLE_TUNNEL_BW_ALLOCATION,     &dpRegkeyDatabase.bForceDisableTunnelBwAllocation, DP_REG_VAL_BOOL}
+    {NV_DP_REGKEY_DISABLE_TUNNEL_BW_ALLOCATION,     &dpRegkeyDatabase.bForceDisableTunnelBwAllocation, DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_DOWNSPREAD,               &dpRegkeyDatabase.bDownspreadDisabled,             DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_SKIP_ZERO_OUI_CACHE,              &dpRegkeyDatabase.bSkipZeroOuiCache,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_DISABLE_FIX_FOR_5019537,          &dpRegkeyDatabase.bDisable5019537Fix,              DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_FIX_FOR_5147205,           &dpRegkeyDatabase.bEnable5147205Fix,               DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_FORCE_HEAD_SHUTDOWN,              &dpRegkeyDatabase.bForceHeadShutdown,              DP_REG_VAL_BOOL},
+    {NV_DP_REGKEY_ENABLE_LOWER_BPP_CHECK_FOR_DSC,   &dpRegkeyDatabase.bEnableLowerBppCheckForDsc,      DP_REG_VAL_BOOL}
 };
 
 EvoMainLink::EvoMainLink(EvoInterface * provider, Timer * timer) :
@@ -116,7 +125,6 @@ EvoMainLink::EvoMainLink(EvoInterface * provider, Timer * timer) :
     this->applyRegkeyOverrides();
 
     _isDynamicMuxCapable       = false;
-    _isMDMEnabled              = false;
     _isLTPhyRepeaterSupported  = true;
     _rmPhyRepeaterCount        = 0;
     dpMemZero(&_DSC, sizeof(_DSC));
@@ -241,17 +249,8 @@ bool EvoMainLink::getEdpPowerData(bool *panelPowerOn, bool *dpcdPowerStateD0)
     }
 }
 
-NvU32 EvoMainLink::streamToHead(NvU32 streamId, DP_SINGLE_HEAD_MULTI_STREAM_PIPELINE_ID streamIdentifier)
-{
-    NvU32 headIndex = 0;
-    NvU32 maxHeads = allHeadMask;
-    NUMSETBITS_32(maxHeads);
-    headIndex = DP_MST_STREAMID_TO_HEAD(streamId, streamIdentifier, maxHeads);
-
-    return headIndex;
-}
-
-NvU32 EvoMainLink::headToStream(NvU32 head, DP_SINGLE_HEAD_MULTI_STREAM_PIPELINE_ID streamIdentifier)
+NvU32 EvoMainLink::headToStream(NvU32 head, bool bSidebandMessageSupported,
+                                DP_SINGLE_HEAD_MULTI_STREAM_PIPELINE_ID streamIdentifier)
 {
     NvU32 streamIndex = 0;
 
@@ -287,19 +286,21 @@ bool EvoMainLink::queryGPUCapability()
 
     _gpuSupportedDpVersions         = dpParams.dpVersionsSupported;
 
+    _minPClkForCompressed           = dpParams.minPClkForCompressed;
+
     if (FLD_TEST_DRF(0073, _CTRL_CMD_DP_GET_CAPS, _MAX_LINK_RATE, _1_62, dpParams.maxLinkRate))
-        _maxLinkRateSupportedGpu = RBR; //in Hz
+        _maxLinkRateSupportedGpu = dp2LinkRate_1_62Gbps; // in 10Mbps
     else if (FLD_TEST_DRF(0073, _CTRL_CMD_DP_GET_CAPS, _MAX_LINK_RATE, _2_70, dpParams.maxLinkRate))
-        _maxLinkRateSupportedGpu = HBR; //in Hz
+        _maxLinkRateSupportedGpu = dp2LinkRate_2_70Gbps; // in 10Mbps
     else if (FLD_TEST_DRF(0073, _CTRL_CMD_DP_GET_CAPS, _MAX_LINK_RATE, _5_40, dpParams.maxLinkRate))
-        _maxLinkRateSupportedGpu = HBR2; //in Hz
+        _maxLinkRateSupportedGpu = dp2LinkRate_5_40Gbps; // in 10Mbps
     else if (FLD_TEST_DRF(0073, _CTRL_CMD_DP_GET_CAPS, _MAX_LINK_RATE, _8_10, dpParams.maxLinkRate))
-        _maxLinkRateSupportedGpu = HBR3; //in Hz
+        _maxLinkRateSupportedGpu = dp2LinkRate_8_10Gbps; // in 10Mbps
     else
     {
         DP_ASSERT(0 && "Unable to get max link rate");
         // Assume that we can at least support RBR.
-        _maxLinkRateSupportedGpu = RBR;
+        _maxLinkRateSupportedGpu = dp2LinkRate_1_62Gbps;
     }
 
     if (!_isDscDisabledByRegkey)
@@ -321,10 +322,14 @@ void EvoMainLink::triggerACT()
     params.subDeviceInstance = this->subdeviceIndex;
     params.displayId = this->displayId;
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_SEND_ACT, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SEND_ACT, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "triggerACT failed!");
+    }
 }
 
-void EvoMainLink::configureHDCPRenegotiate(NvU64 cN, NvU64 cKSV, bool bForceReAuth, bool bRxIDMsgPending){}
+void EvoMainLink::configureHDCPRenegotiate(NvU64 cN, NvU64 cKSV, bool bForceReAuth, bool bRxIDMsgPending) {}
 void EvoMainLink::configureHDCPGetHDCPState(HDCPState &hdcpState)
 {
     // HDCP Not Supported
@@ -374,7 +379,11 @@ void EvoMainLink::configureSingleStream(NvU32 head,
     params.SST.waterMark = waterMark;
     params.SST.bEnableAudioOverRightPanel = bAudioOverRightPanel;
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_STREAM, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_STREAM, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureSingleStream failed!");
+    }
 }
 
 void EvoMainLink::configureSingleHeadMultiStreamMode(NvU32 displayIDs[],
@@ -395,9 +404,12 @@ void EvoMainLink::configureSingleHeadMultiStreamMode(NvU32 displayIDs[],
     params.numStreams = numStreams;
     params.vbiosPrimaryDispIdIndex = vbiosPrimaryDispIdIndex;
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_SINGLE_HEAD_MULTI_STREAM,
-                            &params,
-                            sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_SINGLE_HEAD_MULTI_STREAM,
+                                        &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureSingleHeadMultiStreamMode failed!");
+    }
 }
 
 void EvoMainLink::configureMultiStream(NvU32 head,
@@ -433,7 +445,11 @@ void EvoMainLink::configureMultiStream(NvU32 head,
     params.MST.singleHeadMSTPipeline = streamIdentifier;
     params.MST.bEnableAudioOverRightPanel = bAudioOverRightPanel;
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_STREAM, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_STREAM, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureMultiStream failed!");
+    }
 }
 
 void EvoMainLink::configureMsScratchRegisters(NvU32 address,
@@ -449,7 +465,11 @@ void EvoMainLink::configureMsScratchRegisters(NvU32 address,
     params.hopCount = hopCount;
     params.dpMsDevAddrState = dpMsDevAddrState;
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_RAD_SCRATCH_REG, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_RAD_SCRATCH_REG, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureMsScratchRegisters failed!");
+    }
 }
 
 //
@@ -492,7 +512,8 @@ bool EvoMainLink::setDpStereoMSAParameters(bool bStereoEnable, const NV0073_CTRL
     // implement this rmcontrol.  To avoid that, this class would need to be
     // aware of which evo display HAL is in use.
     //
-    if (ret != NVOS_STATUS_SUCCESS && ret != NVOS_STATUS_ERROR_NOT_SUPPORTED) {
+    if (ret != NVOS_STATUS_SUCCESS && ret != NVOS_STATUS_ERROR_NOT_SUPPORTED)
+    {
         DP_ASSERT(!"Enabling MSA stereo override failed!");
         return false;
     }
@@ -786,7 +807,7 @@ AuxBus::status EvoAuxBus::transaction(Action action, Type type, int address,
     {
         if (devicePlugged)
         {
-            DP_PRINTF(DP_ERROR, "DP> AuxChCtl Failing, if a device is connected you shouldn't be seeing this");
+            DP_PRINTF(DP_WARNING, "DP> AuxChCtl Failing, if a device is connected you shouldn't be seeing this");
         }
         return nack;
     }
@@ -896,6 +917,7 @@ void EvoMainLink::applyRegkeyOverrides()
     _applyLinkBwOverrideWarRegVal        = dpRegkeyDatabase.bLinkBwOverrideWarApplied;
     _enableMSAOverrideOverMST            = dpRegkeyDatabase.bMsaOverMstEnabled;
     _isMSTPCONCapsReadDisabled           = dpRegkeyDatabase.bMSTPCONCapsReadDisabled;
+    _isDownspreadDisabledByRegkey        = dpRegkeyDatabase.bDownspreadDisabled;
 }
 
 NvU32 EvoMainLink::getRegkeyValue(const char *key)
@@ -1013,7 +1035,7 @@ bool EvoMainLink::train(const LinkConfiguration & link, bool force,
         targetIndex = phyRepeaterCount;
     }
 
-    if (!this->isDownspreadSupported())
+    if (!this->isDownspreadSupported() || link.bDisableDownspread || _isDownspreadDisabledByRegkey)
     {
         // If GPU does not support downspread, disabling downspread.
         dpCtrlCmd |= DRF_DEF(0073_CTRL, _DP_CMD, _USE_DOWNSPREAD_SETTING, _FORCE);
@@ -1046,15 +1068,16 @@ bool EvoMainLink::train(const LinkConfiguration & link, bool force,
 
         switch (linkrate)
         {
-            case RBR:
-            case EDP_2_16GHZ:
-            case EDP_2_43GHZ:
-            case HBR:
-            case EDP_3_24GHZ:
-            case EDP_4_32GHZ:
-            case HBR2:
-            case HBR3:
-                linkBw = linkrate / DP_LINK_BW_FREQ_MULTI_MBPS;
+            case dp2LinkRate_1_62Gbps:
+            case dp2LinkRate_2_16Gbps:
+            case dp2LinkRate_2_43Gbps:
+            case dp2LinkRate_2_70Gbps:
+            case dp2LinkRate_3_24Gbps:
+            case dp2LinkRate_4_32Gbps:
+            case dp2LinkRate_5_40Gbps:
+            case dp2LinkRate_6_75Gbps:
+            case dp2LinkRate_8_10Gbps:
+                linkBw = LINK_RATE_10MHZ_TO_270MHZ(linkrate);
                 dpCtrlData = FLD_SET_DRF_NUM(0073_CTRL, _DP_DATA, _SET_LINK_BW,
                                              linkBw, dpCtrlData);
                 break;
@@ -1141,6 +1164,12 @@ bool EvoMainLink::train(const LinkConfiguration & link, bool force,
             break;
         }
 
+        if (FLD_TEST_DRF(0073_CTRL_DP, _ERR, _LINK_STATUS, _DISCONNECTED, err))
+        {
+            // Don't fallback if the device is already gone.
+            break;
+        }
+
         if (FLD_TEST_DRF(0073_CTRL_DP, _CMD, _TRAIN_PHY_REPEATER, _YES, dpCtrlCmd) &&
             FLD_TEST_DRF(0073_CTRL_DP, _ERR, _INVALID_PARAMETER, _ERR, err) &&
             FLD_TEST_DRF(0073_CTRL_DP, _ERR, _TRAIN_PHY_REPEATER, _ERR, err))
@@ -1160,7 +1189,7 @@ bool EvoMainLink::train(const LinkConfiguration & link, bool force,
         if (FLD_TEST_DRF(0073_CTRL_DP, _ERR, _CLOCK_RECOVERY, _ERR, err))
         {
             // If failed CR, check if we need to fallback.
-            if (requestRmLC.peakRate != RBR)
+            if (requestRmLC.peakRate != dp2LinkRate_1_62Gbps)
             {
                 //
                 // We need to fallback on link rate if the following conditions are met:
@@ -1213,7 +1242,7 @@ bool EvoMainLink::train(const LinkConfiguration & link, bool force,
             if (FLD_TEST_DRF(0073_CTRL_DP, _ERR, _CR_DONE_LANE, _0_LANE, err))
             {
                 //Per spec, if link rate has already been reduced to RBR, exit fallback
-                if(requestRmLC.peakRate == RBR || !requestRmLC.lowerConfig())
+                if(requestRmLC.peakRate == dp2LinkRate_1_62Gbps || !requestRmLC.lowerConfig())
                     break;
             }
             else
@@ -1292,35 +1321,6 @@ bool EvoMainLink::getDynamicMuxState(NvU32 *muxState)
     return bIsMuxCapable;
 }
 
-bool EvoMainLink::aquireSema()
-{
-    NV0073_CTRL_DP_AUXCH_SET_SEMA_PARAMS params;
-
-    dpMemZero(&params, sizeof(params));
-    params.subDeviceInstance       = subdeviceIndex;
-    params.displayId               = displayId;
-    params.owner                   = NV0073_CTRL_DP_AUXCH_SET_SEMA_OWNER_RM;
-
-    NvU32 code = provider->rmControl0073(NV0073_CTRL_CMD_DP_AUXCH_SET_SEMA, &params, sizeof(params));
-
-    return code == NVOS_STATUS_SUCCESS;
-}
-
-void EvoMainLink::releaseSema()
-{
-    NV0073_CTRL_DP_AUXCH_SET_SEMA_PARAMS params;
-
-    dpMemZero(&params, sizeof(params));
-    params.subDeviceInstance       = subdeviceIndex;
-    params.displayId               = displayId;
-    params.owner                   = NV0073_CTRL_DP_AUXCH_SET_SEMA_OWNER_RELEASE;
-
-    NvU32 code = provider->rmControl0073(NV0073_CTRL_CMD_DP_AUXCH_SET_SEMA, &params, sizeof(params));
-
-    DP_USED(code);
-    DP_ASSERT(code == NVOS_STATUS_SUCCESS);
-}
-
 void EvoMainLink::configurePowerState(bool bPowerUp)
 {
     NV0073_CTRL_DP_MAIN_LINK_CTRL_PARAMS params;
@@ -1352,7 +1352,8 @@ void EvoMainLink::getLinkConfig(unsigned &laneCount, NvU64 & linkRate)
 
         if (params.linkBW != 0)
         {
-            linkRate = ((NvU64)params.linkBW) * DP_LINK_BW_FREQ_MULTI_MBPS;
+            DP_ASSERT((params.dp2LinkBW == 0) && "dp2LinkBW should be zero if linkBw is not zero");
+            linkRate = LINK_RATE_270MHZ_TO_10MHZ((NvU64)params.linkBW);
         }
         else
         {
@@ -1417,22 +1418,21 @@ bool EvoMainLink::queryAndUpdateDfpParams()
             DP_ASSERT(0 && "maxLinkRate is set improperly in dfp object.");
             // intentionally fall-thru.
         case NV0073_CTRL_DFP_FLAGS_DP_LINK_BW_1_62GBPS:
-            _maxLinkRateSupportedDfp = RBR;
+            _maxLinkRateSupportedDfp = dp2LinkRate_1_62Gbps;
             break;
         case NV0073_CTRL_DFP_FLAGS_DP_LINK_BW_2_70GBPS:
-            _maxLinkRateSupportedDfp = HBR;
+            _maxLinkRateSupportedDfp = dp2LinkRate_2_70Gbps;
             break;
         case NV0073_CTRL_DFP_FLAGS_DP_LINK_BW_5_40GBPS:
-            _maxLinkRateSupportedDfp = HBR2;
+            _maxLinkRateSupportedDfp = dp2LinkRate_5_40Gbps;
             break;
         case NV0073_CTRL_DFP_FLAGS_DP_LINK_BW_8_10GBPS:
-            _maxLinkRateSupportedDfp = HBR3;
+            _maxLinkRateSupportedDfp = dp2LinkRate_8_10Gbps;
             break;
     }
 
 
     _isDynamicMuxCapable = FLD_TEST_DRF(0073, _CTRL_DFP_FLAGS, _DYNAMIC_MUX_CAPABLE, _TRUE, dfpFlags);
-    _isMDMEnabled = FLD_TEST_DRF(0073, _CTRL_DFP_FLAGS, _MDM, _ENABLED, dfpFlags);
 
     return true;
 }
@@ -1586,8 +1586,11 @@ bool EvoMainLink::controlRateGoverning(NvU32 head, bool enable, bool updateNow)
         params.flags |= DRF_DEF(0073_CTRL, _CMD_DP_SET_RATE_GOV_FLAGS, _TRIGGER_MODE, _LOADV);
     }
 
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_RATE_GOV, &params, sizeof params);
-
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_RATE_GOV, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "controlRateGoverning(): Set RateGov failed!");
+    }
     return true;
 }
 
@@ -1715,7 +1718,11 @@ void EvoMainLink::configureTriggerSelect(NvU32 head, DP_SINGLE_HEAD_MULTI_STREAM
     params.subDeviceInstance = subdeviceIndex;
     params.sorIndex = provider->getSorIndex();
     params.singleHeadMSTPipeline = streamIdentifier;
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_TRIGGER_SELECT, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_TRIGGER_SELECT, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureTriggerSelect(): Set Trigger Select failed!");
+    }
 }
 
 void EvoMainLink::configureTriggerAll(NvU32 head, bool enable)
@@ -1724,13 +1731,37 @@ void EvoMainLink::configureTriggerAll(NvU32 head, bool enable)
     params.head = head;
     params.subDeviceInstance = subdeviceIndex;
     params.enable = enable;
-    provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_TRIGGER_ALL, &params, sizeof params);
+    NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_TRIGGER_ALL, &params, sizeof params);
+    if (ret != NVOS_STATUS_SUCCESS)
+    {
+        DP_PRINTF(DP_ERROR, "configureTriggerAll(): Set Trigger All failed!");
+    }
 }
 
 MainLink * DisplayPort::MakeEvoMainLink(EvoInterface * provider, Timer * timer)
 {
     MainLink *main;
-    main = new EvoMainLink(provider, timer);
+    NvU32 nvosStatus;
+    NV0073_CTRL_CMD_DP_GET_CAPS_PARAMS dpParams = {0};
+
+    dpParams.subDeviceInstance = provider->getSubdeviceIndex();
+    nvosStatus = provider->rmControl0073(NV0073_CTRL_CMD_DP_GET_CAPS, &dpParams, sizeof dpParams);
+
+    if (nvosStatus != NVOS_STATUS_SUCCESS)
+    {
+        DP_ASSERT(0 && "Unable to get DP caps params");
+        return NULL;
+    }
+
+    if (FLD_TEST_DRF(0073_CTRL_CMD_DP, _GET_CAPS_DP_VERSIONS_SUPPORTED,
+                     _DP2_0, _YES, dpParams.dpVersionsSupported))
+    {
+        main = new EvoMainLink2x(provider, timer);
+    }
+    else
+    {
+        main = new EvoMainLink(provider, timer);
+    }
     return main;
 }
 
@@ -1809,9 +1840,7 @@ bool EvoMainLink::configureLinkRateTable
         }
     }
 
-    NvU32 code = provider->rmControl0073(
-                NV0073_CTRL_CMD_DP_CONFIG_INDEXED_LINK_RATES,
-                &params, sizeof(params));
+    NvU32 code = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIG_INDEXED_LINK_RATES, &params, sizeof(params));
 
     if ((pLinkRates != NULL ) && (code == NVOS_STATUS_SUCCESS) &&
         (params.linkBwCount <= NV0073_CTRL_DP_MAX_INDEXED_LINK_RATES))
@@ -1821,15 +1850,15 @@ bool EvoMainLink::configureLinkRateTable
         {
             switch (params.linkBwTbl[i])
             {
-                case linkBW_1_62Gbps:
-                case linkBW_2_16Gbps:
-                case linkBW_2_43Gbps:
-                case linkBW_2_70Gbps:
-                case linkBW_3_24Gbps:
-                case linkBW_4_32Gbps:
-                case linkBW_5_40Gbps:
-                case linkBW_8_10Gbps:
-                    pLinkRates->import((NvU8)params.linkBwTbl[i]);
+                case dp2LinkRate_1_62Gbps:
+                case dp2LinkRate_2_16Gbps:
+                case dp2LinkRate_2_43Gbps:
+                case dp2LinkRate_2_70Gbps:
+                case dp2LinkRate_3_24Gbps:
+                case dp2LinkRate_4_32Gbps:
+                case dp2LinkRate_5_40Gbps:
+                case dp2LinkRate_8_10Gbps:
+                    pLinkRates->import((NvU16)params.linkBwTbl[i]);
                     break;
                 default:
                     DP_PRINTF(DP_ERROR, "DP_EVO> %s: Unsupported link rate received",
@@ -1863,9 +1892,7 @@ bool EvoMainLink::configureFec
     params.displayId = displayId;
     params.bEnableFec = bEnableFec;
 
-    NvU32 code = provider->rmControl0073(
-                NV0073_CTRL_CMD_DP_CONFIGURE_FEC,
-                &params, sizeof(params));
+    NvU32 code = provider->rmControl0073(NV0073_CTRL_CMD_DP_CONFIGURE_FEC, &params, sizeof(params));
 
     if (code == NVOS_STATUS_SUCCESS)
     {
