@@ -135,7 +135,6 @@ _krcInitRegistryOverrides
         pKernelRc->bBreakOnRc = NV_TRUE;
     }
 
-
     if (osReadRegistryDword(pGpu,
                             NV_REG_STR_RM_WATCHDOG_TIMEOUT,
                             &pKernelRc->watchdogPersistent.timeoutSecs) !=
@@ -145,6 +144,29 @@ _krcInitRegistryOverrides
         pKernelRc->watchdogPersistent.timeoutSecs =
             NV_REG_STR_RM_WATCHDOG_TIMEOUT_DEFAULT;
     }
+
+    NvU32 data32 = 0;
+    NvU32 bug5203024OverrideTimeouts = (
+        (osReadRegistryDword(pGpu, NV_REG_STR_RM_BUG5203024_OVERRIDE_TIMEOUT,
+                             &data32) == NV_OK) ?
+        data32 :
+        0);
+
+    NvBool bOverrideWatchdogTimeout = (DRF_VAL(_REG_STR,
+                                               _RM_BUG5203024_OVERRIDE_TIMEOUT,
+                                               _FLAGS_SET_RC_WATCHDOG_TIMEOUT,
+                                               bug5203024OverrideTimeouts) ==
+                                       1);
+    if (bOverrideWatchdogTimeout)
+    {
+        pKernelRc->watchdogPersistent.timeoutSecs =
+            DRF_VAL(_REG_STR, _RM_BUG5203024_OVERRIDE_TIMEOUT, _VALUE_MS,
+                    bug5203024OverrideTimeouts) / 1000;
+
+        NV_PRINTF(LEVEL_NOTICE, "RC Watchdog timeout forced to %d seconds.\n",
+                  pKernelRc->watchdogPersistent.timeoutSecs);
+    }
+
     if (osReadRegistryDword(pGpu,
                             NV_REG_STR_RM_WATCHDOG_INTERVAL,
                             &pKernelRc->watchdogPersistent.intervalSecs) !=
@@ -267,7 +289,7 @@ krcReportXid_IMPL
 (
     OBJGPU     *pGpu,
     KernelRc   *pKernelRc,
-    NvU32       exceptType,
+    XidContext  context,
     const char *pMsg
 )
 {
@@ -326,20 +348,36 @@ krcReportXid_IMPL
         _krcLogUuidOnce(pGpu, pKernelRc);
 
         krcGetMigAttributionForError_HAL(pKernelRc,
-                                         exceptType,
+                                         context.xid,
                                          &gpuPartitionId,
                                          &computeInstanceId);
 
+        NvBool bPrintRootCause = (
+            (context.xid == ROBUST_CHANNEL_PREEMPTIVE_REMOVAL) &&
+            (context.rootCause.preemptiveRemovalPreviousXid != 0));
+
+        char rootCauseXidStr[64] = "";
+        if (bPrintRootCause)
+        {
+            nvDbgSnprintf(rootCauseXidStr,
+                          sizeof(rootCauseXidStr),
+            // this space -v- is intentional
+                          " caused by previous Xid %d",
+                          context.rootCause.preemptiveRemovalPreviousXid);
+        }
+
         // Code-generating macro to reduce duplication
         #define XID_PRINT_WITH_ATTR(attr, ...)                                          \
             do {                                                                        \
                 if (procName != NULL)                                                   \
-                    portDbgPrintf("NVRM: Xid (" attr "): %d, pid=%s, name=%s, %s\n",    \
-                                  __VA_ARGS__, exceptType, pidStr, procName,            \
-                                  pMsg != NULL ? pMsg : "");                            \
+                    portDbgPrintf("NVRM: Xid (" attr "): %d, pid=%s, name=%s, %s%s\n",  \
+                                  __VA_ARGS__, context.xid, pidStr, procName,           \
+                                  pMsg != NULL ? pMsg : "",                             \
+                                  rootCauseXidStr);                                     \
                 else                                                                    \
-                    portDbgPrintf("NVRM: Xid (" attr "): %d, %s\n",                     \
-                                  __VA_ARGS__, exceptType, pMsg != NULL ? pMsg : "");   \
+                    portDbgPrintf("NVRM: Xid (" attr "): %d, %s%s\n",                   \
+                                  __VA_ARGS__, context.xid, pMsg != NULL ? pMsg : "",   \
+                                  rootCauseXidStr);                                     \
             } while (0)
 
         if (gpuPartitionId    != KMIGMGR_INSTANCE_ATTRIBUTION_ID_INVALID &&
